package com.example.demo.controller;

import com.example.demo.entity.UserEntity;
import com.fasterxml.jackson.databind.ObjectMapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.stream.Collectors;

/**
 * @Project: demo
 * @Site: http://www.lemonban.com
 * @Forum: http://testingpai.com
 * @Copyright: ©2021 版权所有 湖南省零檬信息技术有限公司
 * @Author: sanbao
 * @Create: 2021-11-23 14:14
 * @Desc： 用户控制器，提供用户访问接口。
 **/
@Api(tags = "用户信息")
@RestController
@RequestMapping("/user")
public class UserController {
    @Autowired
    List<UserEntity> userEntities;

    /**
     * 用户查询
     * @return
     */
    @ApiOperation("查询")
    @GetMapping("/")
    public List<UserEntity> query(){
        return this.userEntities;
    }

    /**
     * 根据ID获取数据
     * @param id
     * @return
     */
    @ApiOperation("根据ID获取")
    @GetMapping("/{id}")
    public UserEntity getById(@PathVariable Integer id){
        return this.userEntities.stream().filter(s->s.getId() == id).findFirst().orElse(null);
    }

    /**
     * 新增
     * @param userEntity
     */
    @ApiOperation("新增")
    @PostMapping("/")
    public void create(@RequestBody UserEntity userEntity){
        this.userEntities.add(userEntity);
    }

    /**
     * 修改
     * @param userEntity
     */
    @ApiOperation("修改")
    @PutMapping("/")
    public void update(@RequestBody UserEntity userEntity){
        //根据获取已经存在的数据
        UserEntity existUserEntity = this.userEntities.stream().filter(item->item.getId() == userEntity.getId()).findFirst().orElse(null);
        //拷贝属性，即更新
        BeanUtils.copyProperties(userEntity,existUserEntity);
    }

    /**
     * 删除
     * @param id
     */
    @ApiOperation("删除")
    @DeleteMapping("/{id}")
    public void deleteById(@PathVariable Integer id){
        //过滤出非当前id的所有数据，即实现删除
        this.userEntities = this.userEntities.stream().filter(s->s.getId() != id).collect(Collectors.toList());
    }
}